==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/test_environment_setup_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe TestEnvironmentSetupController do
  fixtures :cms_projects, :cms_publishes, :cms_published_projects

  def login_as_admin
    login_as("admin")
  end

  before(:each) do
    login_as_admin
    CmsPublish.destroy_all
    CmsPublishedProject.destroy_all
  end

  describe "GET index" do
    it "should get index" do
      get :index
      response.should be_success
      assigns(:cms_publish).should_not be_nil
    end
  end

  describe "POST create" do
    before(:each) do
      Time.stub!(:now).and_return(Time.local(2009, 1, 5, 11, 00, 00))
    end

    it "テスト環境を作成" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2009, 1, 15, 11, 00, 00)
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == []
    end

    it "テスト環境を作成　プロジェクトID指定" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2009, 1, 15, 11, 00, 00),
          :project_ids =>[cms_projects(:cms_projects_00003).id, cms_projects(:cms_projects_00004).id]
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == [3, 6]
    end

    it "対象日時＜現在日時の場合はエラー" do
      post :create, :cms_publish => {:designated_at => Time.local(2008, 1, 1, 11, 00, 00)}
      response.should render_template("index")
    end
  end
end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/test_environment_setup_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe TestEnvironmentSetupController do
  fixtures :cms_projects, :cms_publishes, :cms_published_projects

  def login_as_admin
    login_as("admin")
  end

  before(:each) do
    login_as_admin
    CmsPublish.destroy_all
    CmsPublishedProject.destroy_all
  end

  describe "GET index" do
    it "should get index" do
      get :index
      response.should be_success
      assigns(:cms_publish).should_not be_nil
    end
  end

  describe "POST create" do
    before(:each) do
      Time.stub!(:now).and_return(Time.local(2009, 1, 5, 11, 00, 00))
    end

    it "テスト環境を作成 プロジェクトID指定なし" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2009, 1, 15, 11, 00, 00)
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == []
    end

    # project2の公開期間 : 2009-02-02 10:00:00 ～ 2020-02-02 10:00:00
    # project4の公開期間 : 2010-07-30 16:07:00 ～ 2010-12-30 16:07:00
    it "テスト環境を作成 project2,4を指定 対象日時がproject4の公開期間より前の場合" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2010, 7, 30, 16, 06, 59),
          :project_ids =>[cms_projects(:cms_projects_00002).id, cms_projects(:cms_projects_00004).id]
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == [2]
    end

    it "テスト環境を作成 project2,4を指定 対象日時がproject4の公開期開始時刻と同じ場合" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2010, 7, 30, 16, 07, 00),
          :project_ids =>[cms_projects(:cms_projects_00002).id, cms_projects(:cms_projects_00004).id]
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == [2, 6]
    end

    it "テスト環境を作成 project2,4を指定 対象日時がproject4の公開終了時刻と同じ場合" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2010, 12, 30, 16, 07, 00),
          :project_ids =>[cms_projects(:cms_projects_00002).id, cms_projects(:cms_projects_00004).id]
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == [2, 6]
    end

    it "テスト環境を作成 project2,4を指定 対象日時がproject4の公開期間より後の場合" do
      lambda {
        post :create, :cms_publish => {
          :designated_at => Time.local(2010, 12, 30, 16, 07, 01),
          :project_ids =>[cms_projects(:cms_projects_00002).id, cms_projects(:cms_projects_00004).id]
          }
      }.should change(CmsPublish, :count).by(1)
      response.should redirect_to(:controller => 'test_environment_setup', :action => 'index')
      publish = CmsPublish.find(:first, :include => :cms_published_projects)
      publish.target_key.should == :test
      publish.status_key.should == :waiting
      publish.cms_published_projects.map(&:cms_project_id).sort.should == [2]
    end

    it "対象日時＜現在日時の場合はエラー" do
      post :create, :cms_publish => {:designated_at => Time.local(2008, 1, 1, 11, 00, 00)}
      response.should render_template("index")
    end
  end
end
